#
# spec file for package yast2-scanner
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Used to exclude libX11, libXau, libxcb, and libxcb-xlib from the requires list
# which are pulled in by Autoreqprov because of the displaytest tool:
%define my_requires /tmp/my-requires
Name:           yast2-scanner
Version:        5.0.0
Release:        1.1
Summary:        YaST2 - Scanner Configuration
License:        GPL-2.0-only
Group:          System/YaST
URL:            https://github.com/yast/yast-scanner
Source0:        %{name}-%{version}.tar.bz2
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  doxygen
BuildRequires:  libtool
BuildRequires:  libxslt
BuildRequires:  perl-XML-Writer
BuildRequires:  sgml-skel
BuildRequires:  update-desktop-files
BuildRequires:  xorg-x11-libX11-devel
BuildRequires:  yast2
BuildRequires:  yast2-devtools >= 4.4.0
Requires:       yast2
Requires:       yast2-ruby-bindings >= 1.0.0

%description
This package provides support for the configuration of USB scanners,
SCSI scanners, scanners in HP all-in-one devices, and scanning via
network (i.e. use a remote scanner via another host in the network).

Parallel port scanners and network scanners (i.e. a scanner which is
directly accessible in the network) cannot be configured with this
tool, except for such scanners in HP all-in-one devices. Usually those
devices must be configured manually. For more information see
http://www.sane-project.org/ and the documentation in the package
"sane-backends".

%prep
%setup -q

%build
%yast_build

%install
%yast_install

# Exclude libX11, libXau, libxcb, and libxcb-xlib from the requires list
# which are pulled in by Autoreqprov because of the displaytest tool:
cat << EOF > %{my_requires}
grep -v 'displaytest' | %{__find_requires}
EOF
chmod 755 %{my_requires}
%define __find_requires %{my_requires}
%yast_metainfo

%files
%license COPYING
%{yast_yncludedir}
%{yast_clientdir}
%{yast_moduledir}
%{yast_desktopdir}
%{yast_metainfodir}
%{yast_ybindir}
%{yast_ybindir}
%{yast_icondir}

%changelog
* Wed Aug 30 2023 Josef Reidinger <jreidinger@suse.cz>
- 5.0.0 (bsc#1185510)
* Fri Mar  3 2023 Ladislav Slezák <lslezak@suse.cz>
- Bump version to 4.6.0 (bsc#1208913)
* Fri Sep  9 2022 Michal Filka <mfilka@suse.com>
- bsc#1203227
  - Replaced egrep with grep -E.
- 4.5.1
* Wed Apr  6 2022 Ladislav Slezák <lslezak@suse.cz>
- Bump version to 4.5.0 (bsc#1198109)
* Tue Apr 20 2021 Dirk Müller <dmueller@suse.com>
- stop packaging docdir, it only contained the license which
  is now in licensedir (bsc#1184897)
- spec file cleanups
- 4.4.1
* Tue Apr 20 2021 Ladislav Slezák <lslezak@suse.cz>
- 4.4.0
* Fri May 31 2019 Stasiek Michalski <hellcp@mailbox.org>
- Add metainfo (fate#319035)
- Revamp spec
- Replace GenericName with Comment
- 4.2.0
* Tue Feb 26 2019 José Iván López González <jlopez@suse.com>
- Version bump (bsc#1124009)
- 4.1.0
* Mon Nov 26 2018 Noah Davis <noahadvs@gmail.com>
- Provide icon with module (boo#1109310)
- 4.0.3
* Tue Oct 16 2018 schubi@suse.de
- Added license file to spec.
* Mon Aug 20 2018 schubi@suse.de
- Switched license in spec file from SPDX2 to SPDX3 format.
* Thu Jun 28 2018 schubi@suse.de
- Added additional searchkeys to desktop file (fate#321043).
- 4.0.2
* Thu Apr 12 2018 knut.anderssen@suse.com
- bnc#859353
  - Adapted setup_network_scanner_config using the systemd sane
    socket unit when exists.
- 4.0.1
* Fri Apr  6 2018 mfilka@suse.com
- bnc#1087957 - version bump
- 4.0.0
* Tue Apr  4 2017 mfilka@suse.com
- bnc#1026027
  - dropped call to insserv when enabling xinetd
- 3.2.1
* Mon Apr  3 2017 mfilka@suse.com
- bnc#1026027
  - dropped calls to insserv related to HP's obsoleted services.
- 3.2.0
* Tue Jun  7 2016 igonzalezsosa@suse.com
- Stop generating autodocs (fate#320356)
- 3.1.3
* Fri Dec  5 2014 jsmeix@suse.de
- setup_network_scanner_config.with_systemd_support is an
  enhancement for /usr/lib/YaST2/bin/setup_network_scanner_config
  that provides additional support for systemd (bnc#859353).
* Fri Dec  5 2014 jsmeix@suse.de
- use_fast_append_instead_of_slow_add.diff replaces
  slow Builtins.add() with fast '<<' append operator
  where needed to avoid "hang up impression" (bnc#877516).
* Thu Dec  4 2014 jreidinger@suse.com
- remove X-KDE-Library from desktop file (bnc#899104)
* Wed Nov 13 2013 jreidinger@suse.com
- Add explicit COPYING file
* Thu Sep 19 2013 lslezak@suse.cz
- do not use *.spec.in template, use *.spec file with RPM macros
  instead
- 3.1.0
* Wed Jul 31 2013 yast-devel@opensuse.org
- converted from YCP to Ruby by YCP Killer
  (https://github.com/yast/ycp-killer)
- version 3.0.0
* Tue May  8 2012 jsmeix@suse.de
- V 2.23.0
- Third party driver "epkowa" responsibility transferred
  from Avasys to Epson (bnc#746038).
- Use ButtonBox widget in src/Scanner.ycp (bnc#701263).
- Fixed typo in help text "UDB" -> "USB" (bnc#703235).
- Replaced the HTTP URLs to the Style Guide with the plain text
  "YaST Style Guide (dated Tue, 04 Nov 2008)" (bnc#732272).
* Thu Mar 29 2012 jsuchome@suse.cz
- merge proofread texts
* Fri Dec 16 2011 coolo@suse.com
- it's actually GPL 2.0 only
* Fri Nov 25 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Fri Aug  5 2011 tgoettlicher@suse.de
- fixed .desktop file (bnc #681249)
* Thu Feb 10 2011 jsmeix@suse.de
- V 2.20.1
- Changed the number for DownloadProgress to multiple of 1024
  to get nicer looking "nnn.0 KB" texts in the Gtk UI.
  Using 921600 because /var/lib/YaST2/scanner_database.ycp
  is about 890000 bytes in openSUSE 11.4
  (see openSUSE/Novell Bugzilla bnc#670675).
* Thu Sep 23 2010 jsmeix@suse.de
- V 2.20.0
- Let the ConfigureBackendDialog automatically proceed to the next
  dialog (i.e. to the overview dialog) after successful backend
  activation (see openSUSE/Novell Bugzilla bnc#636083).
- Fix determine_active_scanner_backends so that it also detects
  active backends with '_' or '-' characters in the backend name
  (see openSUSE/Novell Bugzilla bnc#641111).
* Tue Apr  6 2010 jsmeix@suse.de
- V 2.19.2
- HAL is deprecated and does no longer support to grant read/write
  device access permissions for scanners to the currently logged
  in "desktop" user. Therefore the HAL related code was removed
  (see Novell/Suse Bugzilla bnc#593946).
- Implemented Novell/Suse Bugzilla bnc#578203 enhancement
  to show in the model selection list  "unmaintained driver"
  and added info to the help text so that the user knows
  in advance whether or not he could expect some help
  if there are issues with an unmaintained driver.
- In case of the "net" meta-backend, the [Edit] button in the
  OverviewDialog now also launches the "Scanning via Network"
  dialog even when the "net" meta-backend did not recognize
  a scanner (see Novell/Suse Bugzilla bnc#578104).
* Thu Jan 21 2010 jsmeix@suse.de
- V 2.19.1
- Adapted to no longer try to install the proprietary packages
  iscan, iscan-proprietary-drivers, and iscan-firmware.
  Instead show a meaningful user information
  when one of those Epson models is to be set up
  which require the proprietary Iscan software
  so that the user can download and install
  the right packages from Avasys on his own
  (see Novell/Suse Bugzilla bnc#569917).
- Reduced too long help text 'regarding firewall' but
  added a link to 'SDB:CUPS and SANE Firewall settings' at
  http://en.opensuse.org/SDB:CUPS_and_SANE_Firewall_settings
  (see Novell/Suse Bugzilla bnc#551282).
* Wed Jan 13 2010 kmachalkova@suse.cz
- Adjusted .desktop file(s) to wrap /sbin/yast2/ calls in xdg-su
  where root privileges are needed, removed X-KDE-SubstituteUID key
  (see Novell/Suse Bugzilla bnc#540627 and bnc#550073).
* Wed Dec 23 2009 jsmeix@suse.de
- V 2.19.0
- Replaced overcomplicated but nevertheless mostly useless code
  for using the YaST SuSEFirewall module by simple generic code
  in a ShowFirewallPopup function in the same way as it works
  for yast2-printer (compare Novell/Suse Bugzilla bnc#549065)
  and enhanced the help text "Regarding Firewall",
  (see Novell/Suse Bugzilla bnc#551282).
- Fixed duplicate button widget with ID `back by
  calling Wizard::HideBackButton() before calling
  Wizard::SetAbortButton(`back,Label::CancelButton()), see
  http://lists.opensuse.org/opensuse-factory/2009-10/msg00528.html
- Added X-KDE-SubstituteUID=true to src/scanner.desktop
  (see Novell/Suse Bugzilla bnc#550073).
* Wed Feb 11 2009 jsmeix@suse.de
- V 2.18.0
- Fixed a typo in a text in Scanner.ycp
  (see Novell/Suse Bugzilla bnc#374628 in particular comment #18).
* Thu Dec  4 2008 jsmeix@suse.de
- V 2.17.5
- Since openSUSE 11.1 'usb_device' must be replaced by 'usb' in
  HAL fdi files (see Novell/Suse Bugzilla bnc#438867).
  Adapted test_and_set_scanner_access_permissions so that it
  works for openSUSE 11.1 and is still to some extent
  backward compatible with openSUSE 11.0.
* Wed Dec  3 2008 jsmeix@suse.de
- V 2.17.4
- Using /usr/share/hal/fdi/information/20thirdparty/70-scanner.fdi
  instead of /etc/hal/fdi/policy/10osvendor/70-scanner.fdi
  and /etc/hal/fdi/information/20thirdparty/80-scanner.fdi
  instead of /etc/hal/fdi/policy/10osvendor/80-scanner.fdi
  (see Novell/Suse Bugzilla bnc#438867).
* Fri Nov 21 2008 jsmeix@suse.de
- V 2.17.3
- Removed the "Cancel" button from the Overview dialog
  because there is nothing to "Cancel" here.
  Do no longer restore the outdated default button names
  when a dialog is closed to avoid too many visible
  changes of button names.
  (See Novell/Suse Bugzilla bnc#440560).
* Tue Nov  4 2008 jsmeix@suse.de
- V 2.17.2
- Removed the "Back" button from the Overview dialog
  and renamed other buttons according to new style guide
  by manually overwriting the Wizard module defaults
  (see Novell/Suse Bugzilla bnc#440560 comment #5).
- Replaced Report with Popup and used Popup::ErrorDetails
  to show stderr when commands failed (without any change
  for translated texts).
* Wed Sep 10 2008 jsmeix@suse.de
- V 2.17.1
  Run test_and_set_scanner_access_permissions also
  for the normal test via the TestBackend function
  (see Novell/Suse Bugzilla bnc#340173).
* Wed Sep 10 2008 jsmeix@suse.de
- V 2.17.0
- Applied proofread texts.
- Enforce a safe environment for ExecuteBashCommand.
- Added an translatable error message to DetermineActiveScanners
  if there is no response from the 'scanimage' command
  (see V 2.16.9 and Novell/Suse Bugzilla bnc#387555).
- Added an translatable message to SetScannerAccessPermissions
  if HAL does not know about the scanner
  (see V 2.16.7 and Novell/Suse Bugzilla bnc#340173).
* Fri May 16 2008 jsrain@suse.cz
- added categories Settings and System into desktop file
  (bnc #382778)
* Thu May  8 2008 jsmeix@suse.de
- V 2.16.10
- Implemented a progress bar while creating the scanner database
  without any new or changed text because of the 'text freeze'
  (see Novell/Suse Bugzilla bnc#388144).
* Wed May  7 2008 jsmeix@suse.de
- V 2.16.9
- Added an explanatory error message to determine_active_scanners
  if there is no response from the 'scanimage' command.
  Because of the YaST 'text freeze' this error message cannot be
  translated for openSUSE 11.0 so that currently it is only a
  simple stderr message, (see Novell/Suse Bugzilla bnc#387555).
* Tue Apr 29 2008 jsmeix@suse.de
- V 2.16.8
- Skipped "SCSI via USB" scanners in autodetect_scanners
  (see Novell/Suse Bugzilla bnc#382744).
* Tue Apr 22 2008 jsmeix@suse.de
- V 2.16.7
- Added tests to test_and_set_scanner_access_permissions
  if HAL knows about the scanner and show an explanatory
  error message if not. The error message is only shown
  when a driver is activated but not if a driver is
  deactivated. Because of the YaST 'text freeze' this
  error message cannot be translated for openSUSE 11.0
  so that currently it is only a simple stderr message,
  (see Novell/Suse Bugzilla bnc#340173).
* Thu Apr 17 2008 jsmeix@suse.de
- V 2.16.6
- In the test_and_set_scanner_access_permissions script
  use info.subsystem instead of the deprecated info.bus
  for the HAL 80-scanner.fdi file.
* Tue Apr 15 2008 jsmeix@suse.de
- V 2.16.5
- Add an exception to Scanner.ycp so that the fallback entry
  for the hpaio driver with the special USB ID "0x03f0:0x0000"
  is preselected for all HPLIP USB all-in-one devices
  which are autodetected by "hp-probe -busb -escan"
  in /usr/lib/YaST2/bin/autodetect_scanners.
- Since HPLIP version 2.8.4 there is no longer any startup daemon.
  I.e. the hpaio driver is now just a normal driver.
  The hplip init script still exists and was adapted to provide
  backward compatibility but all it does is to stop a possibly
  running hplip daemon.
  Accordingly the setup_hplip_scanner_service script was adapted
  to only disable both ptal and hplip completely.
  As a consequence some special popups regarding the hplip service
  were removed and the help text was simplified.
* Wed Apr  9 2008 jsmeix@suse.de
- V 2.16.4
- Modified yast2-scanner.spec.in to exclude displaytest from the
  files which are sent to /usr/lib/rpm/find-requires so that the
  yast2-scanner RPM does no longer require X libraries (libX11,
  libXau, libxcb, and libxcb-xlib) so that it can be installed
  in a system without X.
  Nevertheless it is still architecture dependant because of its
  displaytest binary.
  It does not matter if displaytest fails orderly because its
  XOpenDisplay call fails or if it crashes because of missing
  libraries. All what matters is that displaytest finds out
  if a graphical window can be opened or not.
* Wed Mar 26 2008 jsmeix@suse.de
- V 2.16.3
- Let "Restart Detection" toggle the autodetection behaviour
  (see Novell/Suse Bugzilla bnc#310518).
- Enhanced how hp-setup is launched to be more fail-safe.
  In particular added a small C program displaytest which tests
  with XOpenDisplay whether or not a X window can be opened
  (there is no such tool available in xorg-x11) which makes
  yast2-scanner no longer a noarch RPM.
* Tue Mar 25 2008 jsmeix@suse.de
- V 2.16.2
- Added much better HP all-in-one device support.
  Those devices are now autodetected at the USB and if there
  is already a CUPS queue (the latter in particular for network
  HP all-in-one devices which do not work without a CUPS queue)
  and additionally hp-setup can be launched.
- Initially show only USB scanners with known USB IDs.
  Show all USB devices which look like scanners only after
  "Restart Detection" (see Novell/Suse Bugzilla bnc#310518).
* Wed Mar 19 2008 jsmeix@suse.de
- V 2.16.1
- Added hint how to set up HP all-in-one network scanners
  to the help text (see Novell/Suse Bugzilla bnc#310476).
- Replaced the "scanimage -d ... -T" test
  by "scanimage -d ... -v >/dev/null"
  (see Novell/Suse Bugzilla bnc#344534).
* Tue Mar 18 2008 jsmeix@suse.de
- V 2.16.0
- Removed the RPM test for "sane-backends" from
  create_scanner_database because all what matters in this script
  is whether or not the description files exist.
  Furthermore the YaST scanner module tests during startup
  if "sane-backends" is installed (and installs it if not).
- Skipped "SCSI via USB" scanners in
  test_and_set_scanner_access_permissions
  (see Novell/Suse Bugzilla bnc#341565).
- Added more explanatory text for the proprietary iscan driver
  on x86_64 (see Novell/Suse Bugzilla bnc#337816).
* Mon Mar 17 2008 jsrain@suse.cz
- Added 'StartupNotify=true' to the desktop file
  (see Novell/Suse Bugzilla bnc#304964).
* Thu Jul 19 2007 jsmeix@suse.de
- V 2.15.5
- Replaced "installation source" by "repository" in the texts.
* Wed Jul 18 2007 jsmeix@suse.de
- V 2.15.4
- Mentioned in the help text that USB devices which are
  no scanners might be detected as a USB scanner
  (see Novell/Suse Bugzilla bnc#260991).
* Thu Jun 21 2007 jsmeix@suse.de
- V 2.15.3
- Adapted test_and_set_scanner_access_permissions to be prepared
  for HPLIP version 2.x.
* Wed Jun 13 2007 jsmeix@suse.de
- V 2.15.2
- Adapted test_and_set_scanner_access_permissions according to the
  currently newest changes in HAL (see Novell Bugzilla bnc#250659)
  and added a test to make sure that the USB verdor and product IDs
  do not contain only zeroes (see Novell/Suse Bugzilla bnc#283132).
- Adapted setup_hplip_scanner_service to be prepared for
  HPLIP version 2.x (but be backward compatible).
* Fri May 25 2007 jsrain@suse.cz
- Removed outdated translations from .desktop-files
  (see Novell/Suse Bugzilla bnc#271209).
* Tue Apr 17 2007 jsmeix@suse.de
- V 2.15.1
- Added test for Package::Available == nil (when there is no
  installation source available).
* Mon Jan 29 2007 jsmeix@suse.de
- V 2.15.0
- Package 'sane' was renamed into 'sane-backends'.
  Package 'hp-officeJet' was dropped.
  Adapted it so that it works with 'sane-backends'
  and dropped support for 'hp-officeJet'.
* Wed Nov 29 2006 jsmeix@suse.de
- V 2.14.11
- Fixed test_and_set_scanner_access_permissions to search only
  in field 2 of the lsscsi output if it is SCSI type "scanner" and
  to search only in field 3 if it is manufactuer "HP" or "EPSON"
  (see Novell/Suse Bugzilla bnc#223875).
* Mon Nov 20 2006 jsmeix@suse.de
- V 2.14.10
- Fixed OverviewDialog() regarding the 'net' meta-backend so that
  click 'Edit' or 'Delete' launches the network scanning dialog
  if the 'net' meta-backend is used.
- Fixed OverviewContents() so that a (local) autodetected scanner
  is show to the user even if its device (e.g. "libusb:001:002")
  appears also in the device info of the 'net' meta-backend for a
  remote scanner (e.g. "net:192.168.1.2:epson:libusb:001:002").
* Fri Nov 17 2006 jsmeix@suse.de
- V 2.14.9
- Fixed creation of interface_and_usbid_string in the model_items
  list (set interface_and_usbid_string to the empty string if
  the scanner has neither SCSI nor USB).
* Thu Nov 16 2006 jsmeix@suse.de
- V 2.14.8
- Using better syntax for the model preselection code
  (regarding access integer values in term types).
* Wed Nov 15 2006 jsmeix@suse.de
- V 2.14.7
- Improved how a model is preselected in the model_items list.
* Tue Nov  7 2006 jsmeix@suse.de
- V 2.14.6
- Improved when the the info regarding outdated hpoj pops up.
  Moved it from the ActivateBackend function directly into the
  SelectModelDialog which avoids that the user must go "Back"
  to the SelectModelDialog to select the up-to-date hpaio driver.
- Added a help text regarding the most often reported problem
  regarding scanner setup (a driver is set up but no scanner
  is recognized by the driver).
* Mon Nov  6 2006 jsmeix@suse.de
- V 2.14.5
- Improved test_and_set_scanner_access_permissions to make
  manufacturer specific entries for SCSI "processors".
- Fixed when the info regarding outdated hpoj pops up (must be
  before the hp-officeJet package may get installed).
* Tue Oct 31 2006 jsmeix@suse.de
- V 2.14.4
- Replaced complicated SetUsbScannerAccessPermissions()
  and SetScsiScannerAccessPermissions() functions by a simpler
  test_and_set_scanner_access_permissions script and call this
  script from a simple SetScannerAccessPermissions() function
  (for background info see Novell/Suse Bugzilla bnc#160899).
- Added user information regarding outdated hpoj driver.
- Fixed possible tmp races in some scripts (only $TMP_DATA
  was created using mktemp but not $TMP_DATA.raw).
* Mon Sep 11 2006 jsmeix@suse.de
- V 2.14.3
- Disable showing Progress from SuSEFirewall::Read call and
  SuSEFirewall::Write call to follow "a YaST style"
  (see Novell/Suse Bugzilla bnc#202351).
* Fri Aug 18 2006 jsmeix@suse.de
- V 2.14.2
- Improved the user information when errors happen in
  SetScsiScannerAccessPermissions().
- Changed a misleading map name: "bash_result"->"result"
* Thu Aug 17 2006 jsmeix@suse.de
- V 2.14.1
- Improved the automated pre-selection of an autodetected scanner
  in the list of all available scanner models.
  For USB scanners the "usbid" entries in the desciption files
  are used if available. This results often an unique match
  so that the matching model can be pre-selected in the list.
  For SCSI scanners the first word of the model description
  is used as autodetected manufacturer name to show by default
  only those SCSI scanners of the list of all available models
  where the autodetected manufacturer name is found in the list.
  Added a "Show Complete List" button so that the user can
  easily access all available models if the automated
  pre-selection may result too few models.
- Fixed that empty-looking error messages (e.g. only a linefeed)
  are shown to the user.
* Tue Aug 15 2006 jsmeix@suse.de
- V 2.14.0
- Increased MAXIMUM_WAIT in test_scanner_backend to 120 seconds
  because otherwise it is early aborted for some scanners
  which need a long time to warm up the lamp.
- Test also for "hpfax" in DependantPrintQueueExists() function
  (see Novell/Suse Bugzilla bnc#184824).
- Fixed SetScsiScannerAccessPermissions(): First enable sane-dev
  then (re)start it.
* Thu Mar 23 2006 jsmeix@suse.de
- V 2.13.16
- Added Confirm::MustBeRoot() to the initial ReadDialog()
  which asks a non-root user for confirmation to continue.
* Thu Mar  9 2006 jsmeix@suse.de
- V 2.13.15
- Applied proofread texts.
* Wed Mar  1 2006 jsmeix@suse.de
- V 2.13.14
- Removed the user information to re-plug an USB scanner
  which was added in V 2.13.13, instead added a resmgr call
  to allow normal user access
  (see Novell/Suse Bugzilla bnc#153705).
* Mon Feb 27 2006 jsmeix@suse.de
- V 2.13.13
- Add a uers information to re-plug an USB scanner to trigger
  the udev -> HAL -> resmgr chain to allow normal user access
  (see Novell/Suse Bugzilla bnc#153705).
* Mon Feb 20 2006 jsmeix@suse.de
- V 2.13.12
- In yast2-scanner.spec.in replaced
  BuildRequires: yast2-devel-packages
  with
  BuildRequires: docbook-xsl-stylesheets doxygen libxslt
    perl-XML-Writer sgml-skel update-desktop-files
    yast2 yast2-devtools yast2-testsuite
* Mon Jan 30 2006 jsmeix@suse.de
- V 2.13.11
- Cleaned up code and user dialog for SUSE Firewall settings.
* Thu Jan 26 2006 jsmeix@suse.de
- V 2.13.10
- Show "Possibly Problematic Driver" warning for the "epkowa"
  backend on x86_64 platforms only when it is used from the
  32-bit-only binary-only "iscan" package but not when it is
  used from the natively built "iscan-free" package.
- Changed "Firewall not running or would not be started." text
  to "Firewall is not or should not be running."
  (see Novell/Suse Bugzilla bnc#145522).
* Wed Jan 25 2006 jsmeix@suse.de
- V 2.13.9
- Increased MAXIMUM_WAIT in determine_active_scanners and
  in test_scanner_backend to 60 seconds because otherwise it is
  early aborted for some scanners which need firmware upload
  or which need a long time to warm up the lamp.
* Tue Jan 24 2006 jsmeix@suse.de
- V 2.13.8
- Applied proofread texts.
* Fri Jan 20 2006 jsmeix@suse.de
- V 2.13.7
- Avoid duplicate entries in .../80-scanner.fdi
* Tue Jan 17 2006 jsmeix@suse.de
- V 2.13.6
- Fixed test_scanner_backend and setup_ptal_scanner_service.
- Changed SetUsbScannerAccessPermissions() to write at least
  the comment how to create entries in .../80-scanner.fdi
* Mon Jan 16 2006 jsmeix@suse.de
- V 2.13.5
- Changed SetUsbScannerAccessPermissions() to write
  /etc/hal/fdi/policy/10osvendor/80-scanner.fdi
  (see Novell/Suse Bugzilla bnc#142859).
* Fri Dec  2 2005 jsmeix@suse.de
- V 2.13.4
- Fine-tuning user dialog regarding support for SUSE Firewall.
* Tue Nov 29 2005 jsmeix@suse.de
- V 2.13.3
- Bugfixes regarding support for SUSE Firewall.
* Fri Nov 25 2005 jsmeix@suse.de
- V 2.13.2
- Bugfixes and enhancements regarding support for SUSE Firewall.
* Thu Nov 24 2005 jsmeix@suse.de
- V 2.13.1
- Added support for SUSE Firewall.
* Wed Nov 16 2005 jsmeix@suse.de
- V 2.13.0
- Added support for iscan-free.
* Fri Aug 26 2005 jsmeix@suse.de
- V 2.12.16
- Simplified how USB scanner access is set up for resmgr:
  Ignore whether or not an autodetected USB scanner can be
  recognized also as active scanner.
  I.e. simply grant access to all autodetected USB scanners
  (comment dated 2005-08-26 03:00 MST
  in Novell/Suse Bugzilla bnc#100695).
* Thu Aug 25 2005 jsmeix@suse.de
- V 2.12.15
- Change the method how USB scanner access is set up for resmgr
  from a generic method (using a fixed entry) to a model-specific
  method using USB vendor and product IDs
  (see Novell/Suse Bugzilla bnc#100695).
* Thu Aug 18 2005 jsmeix@suse.de
- V 2.12.14
- Avoid to show duplicate manufacturer name when it is also a part
  of the model name like in "EPSON Epson Perfection 123".
- Fix killing of the time bomb in setup_ptal_scanner_service.
* Wed Aug 17 2005 jsmeix@suse.de
- V 2.12.13
- Changed "/sbin/lsusb" to "/usr/sbin/lsusb" in the help text.
* Tue Aug 16 2005 jsmeix@suse.de
- V 2.12.12
- Applied proofread texts.
* Tue Aug  9 2005 jsrain@suse.cz
- fixed icon name in .desktop file,set title icon (#103024)
- unify help with menu button label (#103026)
- 2.12.11
* Fri Aug  5 2005 jsmeix@suse.de
- V 2.12.10
- Changed from old Wizard_hw to new WizardHW design.
- Implemented new resmgr handling to allow normal users
  to access USB scanners (bug 100695).
- Several minor improvements
  (e.g. restart detection when test failed,
  nicer model name for detected scanners, ...)
* Thu Jul 28 2005 jsmeix@suse.de
- V 2.12.9
- Applied proofread texts.
* Thu Jul 28 2005 jsmeix@suse.de
- V 2.12.8
- Applied proofread scanner.desktop file.
* Mon Jul 11 2005 jsmeix@suse.de
- V 2.12.7
- Added a "restart detection" functionality in the SummaryDialog.
- Did some minor text changes.
* Wed Jul  6 2005 jsmeix@suse.de
- V 2.12.6
- Added tests whether dependant CUPS print queues exists
  and show user information if there are conflicts because
  of dependant CUPS print queues.
  This happens only for HP all-in-one devices and their required
  services hplip or ptal which cannot run at the same time.
* Fri Jul  1 2005 jsmeix@suse.de
- V 2.12.5
- Refined the proofread texts.
- Added many hints and explanations for translators.
- Improved the comments for autogenerated documentation.
- Improved details in tools/*
- Improved details in Scanner.ycp and dialogs.ycp
* Wed Jun 29 2005 jsmeix@suse.de
- V 2.12.4
- Merged the proofread texts.
* Fri Jun 24 2005 jsmeix@suse.de
- V 2.12.3
- Added and improved help texts for scanning in the network.
* Tue May 24 2005 jsmeix@suse.de
- V 2.12.2
- If the scanner was autodetected and when the manufacturer name
  is known, the search string is preset with the manufacturer name
  so that only the scanners which match to the autodetected
  manufacturer are listed.
- Workaround for strange problem (Bug #75709):
  Sometimes AutodetectScanners (i.e. "sane-find-scanner") doesn't
  detect a scanner but usually it works well for a second attempt.
  Therefore AutodetectScanners is simply called one second time
  if it didn't detect a scanner on the first run.
* Fri May 20 2005 jsmeix@suse.de
- V 2.12.1
- Added popup messages regarding iscan/epkowa problems for x86_64
  and for non-i386-compatible architectures (bug #73985).
- Introduced translatable support status strings (bug #73780).
* Wed May 18 2005 jsmeix@suse.de
- V 2.12.0
- Fixed a bug to to find SCSI scanners (avoid false positives).
- Made the "sed" calls in create_scanner_database look nicer.
- Removed the needless additional Popup::TimedOKCancel(...)
  confirmation request before installing additional packages.
- Added "Progress:..." in ActivateBackend() (Bug #74446).
* Wed Mar  2 2005 jsmeix@suse.de
- V 2.11.6
- Applied proofread texts.
- Additionally changed only 'arive' to 'arise' in helps.ycp
* Mon Feb 28 2005 jsmeix@suse.de
- V 2.11.5
- Removed already configured scanners (i.e. active scanners)
  from list of shown autodetected scanners.
- Added time bombs where external programs may hang up.
- Several bug fixes.
* Tue Feb 15 2005 jsmeix@suse.de
- V 2.11.4
- Improved support for scanning via network.
- Several bug fixes.
- Improved the help texts.
* Thu Feb 10 2005 jsmeix@suse.de
- V 2.11.3
- Added support for network scanning
* Mon Feb  7 2005 jsmeix@suse.de
- V 2.11.2
- Added proofread texts.
- Added support for /etc/init.d/sane-dev
* Fri Feb  4 2005 jsmeix@suse.de
- V 2.11.1
- Added HPLIP support.
* Mon Jan 31 2005 jsmeix@suse.de
- V 2.11.0
- Created the help texts.
- Added search function (filter) for the model list.
* Tue Jan 18 2005 jsmeix@suse.de
- V 2.10.99 (will become 2.11.0)
- Complete rewrite from scratch.
  Nothing is used from the old sources
  (except the old changelog entries below).
* Fri Aug 27 2004 jsmeix@suse.de
- V 2.10.5
- Applied proofread texts.
* Mon Aug 23 2004 jsmeix@suse.de
- V 2.10.4
- Define a fallback scanner (in scanner_manual.ycp)
  so that the vendor and model list is not empty
  even if no scanner was autodetected and
  show a warning popup which defaults to abort.
* Fri Aug 13 2004 jsmeix@suse.de
- V 2.10.3
- Fixed the bug that when an USB scanner was not autodetected
  during startup then the manufacturer and model selection list
  has been empty. Nevertheless the list is still empty if no
  USB scanner can be detected during manual USB scanner setup.
  This is o.k. because without USB vendor and model id the
  scanner cannot be made accessible for normal users by resmgr.
- Applied proofread texts.
* Tue Aug  3 2004 jsmeix@suse.de
- V 2.10.2
- In Scanner.ycp and scanner_new:
  Added popup which explains what to to regarding access USB
  scanners for normal users.
- Fixed several syntax errors which are shown by running
  /usr/bin/ycpc -qE -M. -I. *.ycp
  in the src directory.
- Added @moduledir@/Scanner* and @clientdir@/scanner*
  to yast2-scanner.spec.in so that it builds in autobuild.
* Mon Aug  2 2004 jsmeix@suse.de
- V 2.10.1
- In Scanner.ycp and scanner_new:
  Write USB vendor and model entries to /etc/sane.d/<driver>.conf
  and to /etc/hotplug/usb/sane.usermap and test before whether
  such an entry already exists.
- Added several "import ..." so that "y2tool check_ycp src/*.ycp"
  does no longer warn regarding used but not imported stuff.
- Fixed two errors regarding ScannerAutoSequence:
  Wrong type ("any" instead of "symbol" in wizards.ycp).
  Missing "include" of wizards.ycp in scanner_proposal.ycp.
* Thu Jul  1 2004 jsrain@suse.cz
- modified the code layout to use YCP module for storing data, added
  clients for autoinstallation and proposal (not working because of
  further needed changes in the Scanner.ycp module)
* Fri Jun 18 2004 gs@suse.de
- V 2.10.0
- CVS 9.1 branch merged to head
* Wed May  5 2004 gs@suse.de
- V 2.9.17
- messages from proof reading merged back
* Tue May  4 2004 gs@suse.de
- V 2.9.16
- set scanner driver in manual configuration dialog (bug #39940)
* Wed Apr  7 2004 gs@suse.de
- V 2.9.15
- bugfix for #38634 (remove blank in scanner_notfound.ycp)
* Fri Apr  2 2004 gs@suse.de
- V 2.9.14
- license changed to GPL
* Thu Apr  1 2004 gs@suse.de
- V 2.9.13
- recognize HP all-in-one devices correctly
* Wed Mar 24 2004 gs@suse.de
- V 2.9.12
- scannerDB.pm: config file editing improved (maintained copies of
  the /etc/sane.d/<driver>.conf files are not necessary any longer)
* Mon Mar 22 2004 gs@suse.de
- V 2.9.11
- scannerDP.pm: template for plustek driver corrected
* Fri Mar 12 2004 gs@suse.de
- V 2.9.10
- bugfix: call correct dialog on Add button
* Tue Mar  9 2004 gs@suse.de
- V 2.9.9
- adapt to stricter type checking of YCP interpreter
* Mon Mar  8 2004 msvec@suse.cz
- use Sequencer and Service
- set title icon
* Mon Mar  8 2004 gs@suse.de
- V 2.9.8
- adapt USB scanning to libusb usage (kernel 2.6)
* Tue Mar  2 2004 gs@suse.de
- V 2.9.7
- messages from proofreading merged back
* Mon Mar  1 2004 gs@suse.de
- V 2.9.6
- installation of HP all-in-one devices improved
* Thu Feb 26 2004 gs@suse.de
- V 2.9.5
- check for status "unsupported" (scannerDP.pm)
* Thu Feb 26 2004 gs@suse.de
- V 2.9.4
- don't call scanner USB dialog (scanner.o is obsolete)
* Mon Feb  9 2004 arvin@suse.de
- removed config files (*.y2cc)
* Fri Jan 30 2004 msvec@suse.cz
- NI fixes
- 2.9.2
* Fri Nov 21 2003 gs@suse.de
- V 2.9.1
- install kdegraphics3-scan (Kooka)
- some text/layout improvements
- don't show hubs in USB dialog
* Tue Sep  9 2003 gs@suse.de
- V 2.8.13
- activate service hotplug (instead of hotplug_usb)
* Mon Sep  8 2003 gs@suse.de
- V 2.8.12
- merge texts from proof read, remove non UTF-8 letter from comment
* Tue Sep  2 2003 gs@suse.de
- V 2.8.11
- improve the installation of HP all-in-one devices
* Mon Sep  1 2003 gs@suse.de
- V 2.8.10
- popups added for scanners which require a firmware upload
* Fri Aug 29 2003 gs@suse.de
- V 2.8.9
- add a popup which informs the user to configure JetDirect manually
* Tue Aug 26 2003 gs@suse.de
- V 2.8.8
- activate services hotplug_usb and ptal for HP all-in-one devices
* Thu Aug 21 2003 gs@suse.de
- bugfix in scannerDB.pm ( correct path is: /usr/bin/scanimage )
* Mon Aug 18 2003 arvin@suse.de
- use String::CutBlanks
* Mon Aug 11 2003 gs@suse.de
- V 2.8.5
- merge texts from proofread
* Wed Aug  6 2003 gs@suse.de
- V 2.8.4
- identify HP all-in-one in hwinfo scanner list
* Sat Aug  2 2003 arvin@suse.de
- added desktop file
* Wed Jul 23 2003 gs@suse.de
- V 2.8.2
- support of HP all-in-one devices
- internal: use new perl interface (ag_sane, ag_scanner)
- file scanner.desktop added
* Fri Mar 14 2003 gs@suse.de
- parse external scanner descriptions, too, to get the complete
  scanner list (support of HP Office Jet scanners)
* Thu Mar  6 2003 gs@suse.de
- bugfix in scannerDB.pm (correct initialization of $oriline)
  bug #24833
* Mon Mar  3 2003 gs@suse.de
- help text corrected
* Mon Feb 17 2003 gs@suse.de
- write USB scanner data to /etc/hotplug/usb/sane.usermap
* Mon Feb 10 2003 gs@suse.de
- scanner database now is dynamically created from
  SANE scanner description files
* Mon Nov 18 2002 gs@suse.de
- provide SCR::Dir(.sane), SCR::Dir(.scanner),
  improve, update the help text
* Mon Sep  9 2002 freitag@suse.de
- removed some nasty warnings on console (bug #19090)
  disabled Test-Button while scanning to avoid 'double' clicks
* Wed Sep  4 2002 mvidner@suse.cz
- Don't use a temporary file when calling sw_single.
- 2.6.7
* Tue Sep  3 2002 gs@suse.de
- fixed config template for plustek, i.e. wellknown Epson perfection 1650
* Tue Aug 27 2002 jsuchome@suse.cz
- provide/obsolete old translation packages
* Mon Aug 19 2002 gs@suse.de
- more scanner supported (sane-1.0.8)
* Mon Jul 29 2002 gs@suse.de
- comments for translators added
* Mon Jul 29 2002 gs@suse.de
- remove yast2-runlevel from Requires list
- internal changes (remove obsolete include file)
* Fri Jul 12 2002 arvin@suse.de
- use proper namespace for Args and CallFunction (#16776)
* Fri Jul  5 2002 arvin@suse.de
- moved non binary files to /usr/share/YaST2
* Tue Jul  2 2002 msvec@suse.cz
- renamed to yast2-scanner
- 2.6.0
* Tue Mar 26 2002 gs@suse.de
- (#15510) mark installed scanner as configured for hardware detection
* Mon Mar 25 2002 kkaempf@suse.de
- use 'config aware' libhd calls when probing for usb/scsi devices
  (#15483).
* Tue Mar 19 2002 gs@suse.de
- bugfixes: the test scan for network scanners is working again,
  ignore case while comparing installed and connected scanner
- removed dependency on ImageMagick tool convert since the image
  widget is now able to scale by itself
- #14937: it is possible now to close the scanner configuration with
  the window manager
* Fri Mar 15 2002 gs@suse.de
- reworked the config file templates to use the ones from 1.0.7
  (fixing bug #14899)
- parenthesises removed since they break the ycp-perl interface
* Fri Mar  1 2002 gs@suse.de
- some internal changes and bugfixes (hwinfo now also detects
  SCSI scanner, look for exactly matching key in scanner map,
  use correct key "scanner_driver")
* Mon Feb 25 2002 gs@suse.de
- scannerDB: adapt to sane version 1.07
* Mon Feb 18 2002 freitag@suse.de
- bugfix: Printing lines with only comments again, which were blank
  before. Changed call to scanimage for sane version 1.0.7
* Tue Feb  5 2002 gs@suse.de
- bugfix for the scanner agent, internal changes in ycp modules,
- enable service "sane" if a SCSI scanner is connected
* Mon Feb  4 2002 freitag@suse.de
- removed bug that skips the bus in the device file line in the
  scanner conf, makes /dev/usbscanner from usb /dev/usbscanner
- checked the database for sane 1.0.6
* Thu Nov  8 2001 freitag@suse.de
- changed writeConfig-sub to do not write a comment after the device
  file in the backend.conf file in /etc/sane.d. The comment confuses
  at least the mustek and the snapscan backend (bug #12063)
- added mkdir /var/lib/sane to the function that writes the devices
  file in the directory for sane's rcscript. If the directory does
  not exist, the file could not be written which causes a problem
  with the rcscript on system shutdown
- added mustek_usb to the available drivers list.
- corrected path in revertAll from /var/log/sane to /var/lib/sane.
- added snapscan 1236U to the scanner DB
* Thu Sep 20 2001 gs@suse.de
- multiple scanner tests are possible  (bug #11026)
- permissions of /dev/sg? are set correctly to 666 (bug #11035)
* Tue Sep 18 2001 freitag@suse.de
- write /etc/hotplug/usb.usermap for scanners not automatically detected.
  Makes the correct module loaded and unloaded on mounting or
  unmounting of the device.
- better recognition of scanners by whitespace insensitive pattern match.
- added config-template for USB-mustek scanners, they were accidential
  missing.
* Fri Sep 14 2001 freitag@suse.de
- manual USB scanner install works for Scanners not reporting a
  proper vendor/model name
* Wed Sep 12 2001 freitag@suse.de
- fixed bugs in reverting the installation, created files for the
  sane startup and shutdown scripts that fix permissions.
  Bugfix that removes temporaer files, setting the sane permission
  fix variable in rc.config and behaviour in case no scsi device
  was found in manual scanner configuration (bzilla #10310)
* Tue Sep  4 2001 freitag@suse.de
- installation of scsi and usb scanners work now, deletion is also
  working. Networkstation-scanners will be detected and installed.
  Abort also works.
* Mon Aug 20 2001 gs@suse.de
- installation works (except setting the permissions of /dev/sg_
  or /dev/usbscanner to 666),
  manual installation needs some more work,
  delete an scanner configuration does not work
* Mon Aug  6 2001 gs@suse.de
- workflow dialogs completed - but not yet with full functionality
* Thu Mar 22 2001 gs@suse.de
- initial version
